# This file is part of MOXελ.
# Copyright (C) 2023-2024 Antonios P. Sarikas

# MOXελ is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

r"""
This module provides the Lennard-Jones parameters from UFF.
"""

lj_params = {
    "H": [
        22.11417,
        2.571134
    ],
    "B": [
        90.5798,
        3.637539
    ],
    "C": [
        52.83822,
        3.430851
    ],
    "N": [
        34.72226,
        3.260689
    ],
    "O": [
        30.19327,
        3.118146
    ],
    "F": [
        25.16106,
        2.996984
    ],
    "P": [
        153.48244,
        3.694557
    ],
    "S": [
        137.88258,
        3.594776
    ],
    "K": [
        17.61274,
        3.396106
    ],
    "V": [
        8.05154,
        2.800986
    ],
    "Y": [
        36.23192,
        2.980056
    ],
    "I": [
        170.59196,
        4.009044
    ],
    "W": [
        33.71582,
        2.734168
    ],
    "U": [
        11.07086,
        3.024601
    ],
    "He": [
        10.9,
        2.64
    ],
    "Li": [
        12.58053,
        2.183593
    ],
    "Be": [
        42.77379,
        2.445517
    ],
    "Ne": [
        21.13529,
        2.889185
    ],
    "Na": [
        15.09663,
        2.657551
    ],
    "Mg": [
        55.85754,
        2.691405
    ],
    "Al": [
        254.12666,
        4.008153
    ],
    "Si": [
        202.29488,
        3.82641
    ],
    "Cl": [
        114.23119,
        3.516377
    ],
    "Ar": [
        93.0959,
        3.445996
    ],
    "Ca": [
        119.76662,
        3.028165
    ],
    "Sc": [
        9.5612,
        2.935511
    ],
    "Ti": [
        8.55476,
        2.828603
    ],
    "Cr": [
        7.54829,
        2.69319
    ],
    "Mn": [
        6.54187,
        2.637951
    ],
    "Fe": [
        6.54187,
        2.594297
    ],
    "Co": [
        7.04507,
        2.55866
    ],
    "Ni": [
        7.54829,
        2.524807
    ],
    "Cu": [
        2.5161,
        3.11369
    ],
    "Zn": [
        62.39941,
        2.461553
    ],
    "Ga": [
        208.83676,
        3.904809
    ],
    "Ge": [
        190.7208,
        3.813047
    ],
    "As": [
        155.49532,
        3.768502
    ],
    "Se": [
        146.43734,
        3.746229
    ],
    "Br": [
        126.3085,
        3.731975
    ],
    "Kr": [
        110.70864,
        3.689212
    ],
    "Rb": [
        20.12884,
        3.665157
    ],
    "Sr": [
        118.25696,
        3.243762
    ],
    "Zr": [
        34.722256,
        2.783168
    ],
    "Nb": [
        29.69005,
        2.819694
    ],
    "Mo": [
        28.18038,
        2.719023
    ],
    "Ru": [
        28.18038,
        2.639733
    ],
    "Rh": [
        26.67071,
        2.609442
    ],
    "Pd": [
        24.15461,
        2.582715
    ],
    "Ag": [
        18.11596,
        2.804549
    ],
    "Cd": [
        114.73441,
        2.53728
    ],
    "In": [
        301.42944,
        3.976081
    ],
    "Sn": [
        285.32636,
        3.912827
    ],
    "Sb": [
        225.94627,
        3.937772
    ],
    "Te": [
        200.282,
        3.982317
    ],
    "Cs": [
        22.64495,
        4.02419
    ],
    "Ba": [
        183.17248,
        3.298998
    ],
    "La": [
        8.55476,
        3.137745
    ],
    "Ce": [
        6.54187,
        3.168036
    ],
    "Pr": [
        5.03221,
        3.212581
    ],
    "Nd": [
        5.03221,
        3.184963
    ],
    "Sm": [
        4.02577,
        3.135963
    ],
    "Eu": [
        4.02577,
        3.111909
    ],
    "Gd": [
        4.52899,
        3.000547
    ],
    "Tb": [
        3.52255,
        3.074491
    ],
    "Dy": [
        3.52255,
        3.054001
    ],
    "Ho": [
        3.52255,
        3.037074
    ],
    "Er": [
        3.52255,
        3.021038
    ],
    "Tm": [
        3.01933,
        3.005892
    ],
    "Yb": [
        114.73441,
        2.988965
    ],
    "Lu": [
        20.63207,
        3.242871
    ],
    "Hf": [
        36.23192,
        2.798313
    ],
    "Re": [
        33.21259,
        2.631715
    ],
    "Ir": [
        36.73514,
        2.530152
    ],
    "Pt": [
        40.25769,
        2.453535
    ],
    "Au": [
        19.62562,
        2.933729
    ],
    "Hg": [
        193.74012,
        2.409881
    ],
    "Pb": [
        333.63559,
        3.828192
    ],
    "Bi": [
        260.668,
        3.8932
    ],
    "Th": [
        13.08375,
        3.025492
    ],
    "Np": [
        9.5612,
        3.050437
    ],
    "Pu": [
        8.05154,
        3.050437
    ]
}
